# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nlit',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/nlit',
                'lib_path': 'nlit'},
  'syms': { 'nlit.args': {},
            'nlit.biol': {},
            'nlit.bkts': {},
            'nlit.byte': {},
            'nlit.cell': {},
            'nlit.clrs': {},
            'nlit.docs': {},
            'nlit.dund': {},
            'nlit.embs': {},
            'nlit.exps': {},
            'nlit.exts': {},
            'nlit.mods': {},
            'nlit.mthd': {},
            'nlit.narr': {},
            'nlit.nbks': {},
            'nlit.path': {},
            'nlit.plot': {},
            'nlit.sund': {},
            'nlit.tens': {},
            'nlit.tree': {},
            'nlit.unit': {}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/00__init__.ipynb 3
from itertools import chain

from nlit import (
    args, sund, dund, plot, clrs, exps, mthd, embs, biol, cell, path, exts, tree, mods, 
    docs, nbks, narr, tens, unit, byte, bkts
)
from ..args import *
from ..sund import *
from ..dund import *
from ..plot import *
from ..clrs import *
from ..exps import *
from ..mthd import *
from ..embs import *
from ..biol import *
from ..cell import *
from ..path import *
from ..exts import *
from ..tree import *
from ..mods import *
from ..docs import *
from ..nbks import *
from ..narr import *
from ..tens import *
from ..unit import *
from ..byte import *
from ..bkts import *

# %% ../../nbs/00__init__.ipynb 4
for mod in (sund, dund):
    for k in filter(str.isupper, dir(dund)):
        globals()[k] = getattr(dund, k)
        dund.__all__.append(k)

# %% ../../nbs/00__init__.ipynb 5
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (
        args, sund, dund, plot, clrs, exps, mthd, embs, biol, cell, path, exts, tree, mods, 
        docs, nbks, narr, tens, unit, byte, bkts
    )
])))



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'SEP', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SPEC', 'SPECS', 'DEBUG', 'VALUE', 'CUTOFF', 'MIXINS',
           'UNIQUE', 'INPLACE', 'VERBOSE', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV', 'SYMB', 'BEG', 'END', 'POS',
           'NEG', 'LEN', 'DIG', 'BRV', 'FIX']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
SEP = 'sep'

# %% ../nbs/02_args.ipynb 7
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'

# %% ../nbs/02_args.ipynb 8
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 9
DEBUG = 'debug'
VALUE = 'value'

# %% ../nbs/02_args.ipynb 10
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 11
INPLACE = 'inplace'
VERBOSE = 'verbose'

# %% ../nbs/02_args.ipynb 12
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 14
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 16
ABRV = 'abrv'
SYMB = 'symb'

# %% ../nbs/02_args.ipynb 19
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix
